"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = friendlyPseudoClass;

var _isobject = _interopRequireDefault(require("isobject"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var FRIENDLY_PSEUDO_REGEX = /^on([A-Z])/;
var UPPERCASE_REGEX = /([A-Z])/g;
var ON_REGEX = /^on-(.*)/g;
var pseudoElements = ['after', 'before', 'first-letter', 'first-line', 'selection', 'backdrop', 'placeholder', 'marker', 'spelling-error', 'grammar-error'];

function friendlyPseudoClassPlugin(style) {
  for (var property in style) {
    var value = style[property];

    if ((0, _isobject["default"])(value)) {
      var resolvedValue = friendlyPseudoClassPlugin(value);

      if (property.match(FRIENDLY_PSEUDO_REGEX) !== null) {
        var pseudo = property.replace(UPPERCASE_REGEX, function (match) {
          return '-' + match.toLowerCase();
        }).replace(ON_REGEX, function (match, p1) {
          return "".concat(pseudoElements.includes(p1) ? '::' : ':').concat(p1);
        });
        style[pseudo] = resolvedValue;
        delete style[property];
      } else {
        style[property] = resolvedValue;
      }
    }
  }

  return style;
}

function friendlyPseudoClass() {
  return friendlyPseudoClassPlugin;
}